package com.steerinfo.dil.controller;

import com.github.pagehelper.PageHelper;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.service.impl.BmstruckStatementServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/24 17:29
 * @Version:V2.0
 */
@RestController
@RequestMapping("/${api.version}/bmstruckstatement")
public class BmstruckStatementController extends BaseRESTfulController {

    @Autowired
    BmstruckStatementServiceImpl bmstruckStatementService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    ESFeign esFeign;

    /**
     * 展示汽运账单信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示汽运账单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "179", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getTruckStatementList")
    public RESTfulResult getTruckStatementList(@RequestBody(required = false) Map<String, Object> mapValue,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer apiId) {
        List<Map<String, Object>> truckStatementList = bmstruckStatementService.getTruckStatementList(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = bmstruckStatementService.getTruckStatementList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, truckStatementList, columnList);
        return success(data);
    }

    /**
     * 生成汽运账单
     *
     * @param mapList
     * @return
     */
    @ApiModelProperty(value = "生成汽运账单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapList", value = "详单列表", required = false, dataType = "java.util.List"),
    })
    @PostMapping("/addTruckStatement")
    public RESTfulResult addTruckStatement(@RequestBody List<Map<String, Object>> mapList) {
        int code1 = bmstruckStatementService.addTruckStatement(mapList);
        return success(code1);
    }

    /**
     * 展示账单下的详单
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value = "展示账单下的详单", notes = "分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "statementId", value = "账单id", required = false, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "177", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getSaleTruckStatementDetailsOrderList")
    public RESTfulResult getSaleTruckStatementDetailsOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                               Integer pageNum,
                                                               Integer pageSize,
                                                               Integer apiId,
                                                               BigDecimal statementId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        mapValue.put("statementId", statementId);
        List<Map<String, Object>> truckStatementList = bmstruckStatementService.getSaleTruckStatementDetailsOrderList(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = bmstruckStatementService.getSaleTruckStatementDetailsOrderList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, truckStatementList, columnList);
        return success(data);
    }

    /**
     * 生成内转汽运账单
     *
     * @param mapList
     * @return
     */
    @ApiModelProperty(value = "生成内转汽运账单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapList", value = "详单列表", required = false, dataType = "java.util.List"),
    })
    @PostMapping("/addConvertedTruckStatement")
    public RESTfulResult addConvertedTruckStatement(@RequestBody List<Map<String, Object>> mapList, Integer orderType) {
        int code1 = bmstruckStatementService.addConvertedTruckStatement(mapList, orderType);
        return success(code1);
    }

    /**
     * 删除汽运账单
     */
    @PostMapping("/deleteConvertedTruckStatement/{statementId}")
    public RESTfulResult deleteConvertedTruckStatement(@PathVariable("statementId") BigDecimal statementId) {
        bmstruckStatementService.delete(statementId);
        return success("删除成功");
    }

    /**
     * 审批计费账单
     */
    @PostMapping("/updateConvertedTruckStatement/{statementId}")
    public RESTfulResult updateConvertedTruckStatement(@PathVariable("statementId") BigDecimal statementId) {
        bmstruckStatementService.update(statementId);
        return success("修改成功");
    }
}
